#!/usr/bin/env python

from __future__ import print_function

import sys

print("TEST")
sys.stdout.flush()

